; ----------------------------------------------------------------------------;
;	File: median.h                                                            ;
;                                                                             ;
;	Author: OH (c) acam-messelectronic gmbh 2014                              ;
;                                                                             ;
;   Description:                                                              ;
;       median-filter                                                         ;
;           this is a quasi-median-filter.                                    ;
;           The depth of filter is defined by arguments via stack             ;
;                                                                             ;
;           each new Value (X) will be compared with the current median value ;
;           Is the new value smaller or equal to the median value the last    ;
;           value at the list will be replaced by X. Otherwise the first      ;
;           value at the list will be replaced by X.                          ;
;           Afterwords the complete list is sorted. The value at the very     ;
;           middle of the list is returend as new median.                     ;
;                                                                             ;
;   parameter:                                                                ;
;       Akku B              := filter Input and Output                        ;
;       stack - 2           := start address of filter memory                 ;
;       stack - 1           := middle section of filter memory section        ;
;       stack - 0           := last address of filter memory                  ;
;                                                                             ;
;           filter order is defined by last address - start address           ;
;           the memory section has to be reserved for and must not be used    ;
;           otherwise                                                         ;
;                                                                             ;
;                                                                             ;
;                                                                             ;
;   local / temporary ram  (5x)                                               ;
;                                                                             ;
;                                                                             ;
;   usage:                                                                    ;
;       CONST   FILTER_ORDER   5                                              ;
;       CONST   FILTER_START  12                                              ;
;       CONST   FILTER_MIDDLE 12 + (FILTER_ORDER/2)                           ;
;       CONST   FILTER_STOP   12 + FILTER_ORER                                ;
;                                                                             ;
;       ;initialize:                                                          ;
;        push FILTER_START                                                    ;
;        push FILTER_MIDDLE                                                   ;
;        push FILTER_STOP                                                     ;
;        jsb __sub_median_initialize__                                                                     ;
;                                                                             ;
;        ;...                                                                 ;
;        rad Filter_input_value                                               ;
;        move b, r                                                            ;
;        push FILTER_START                                                    ;
;        push FILTER_MIDDLE                                                   ;
;        push FILTER_STOP                                                     ;
;        jsb __sub_median__                                                   ;
;                                                                             ;
; ----------------------------------------------------------------------------;

#ifdef __median_h__
#else
    #define __median_h__
    
CONST __sub_median__            __median_ROM_START__
CONST __sub_median_initialize__ __median_ROM_START__       +  64
CONST __median_ROM_STOP__       __sub_median_initialize__  +  80
    
    
    
#endif