
#include <pcap_config.h>

CONST FIRSTSTART_N 				0	
CONST FIRSTSTART_N_JCD			0+32	
CONST HS_MODE					1					; User defined High Speed Mode bit
CONST HS_MODE_JCD				HS_MODE+32	

; NVRAM Addresses
CONST NV_cdc_result_align			43+960			; Address containing the number of right shifts to be done on the CDC measurement values
													; 1 : 3time rightshift required for larger discharge times && higher averaging
													; 0 : for smaller discharge times
CONST NV_cdc_result_align_mask		1													
	
CONST NV_sub_cdc_gain_corr__	35+960				; Address of __sub_cdc_gain_corr__ value in NVRAM : Reg 35, 3Byte!
CONST NV_BG_TIME       			38+960				; Address of TIMER0 reload value, if DSP is triggered by INTN rising edge, timer is load with this value 


__SOP__:

    jsb _ROM_tdc_dispatch__ 						; In tdc.lib

; main dispatcher return only if on last cycle

   
jcd (FIRSTSTART_N + 32), MK_IDLE
    jsb MK_Initialize

	
MK_IDLE:
	move a, b
	sub a, b				; a := 0
	sign a

		
MK_QUERY_FLAG1:
	jcd RDC_TRIGGERED_N, MK_QUERY_FLAG2
        jcd	TRUE, MK_main
		
MK_QUERY_FLAG2:	
    jcd TIMER0_IRQ_N, MK_QUERY_FLAG3
		bitS TRIG_CDC						; CDC Trigger for Single Conversion Mode driven by TIMER0

        jsb MK_RO_STOP		
		
MK_QUERY_FLAG3:
	jcd INTN_TRIGGERED_N, MK_QUERY_FLAG6
		jcd	INT_TRIG_BG_N, MK_SKIP_BG_TRIG_AT_START
            bitS TRIG_BG					; Band gap refresh when refresh by interrupt is enabled
	MK_SKIP_BG_TRIG_AT_START:
		jsb 	MK_load_timer
		jsb		MK_RO_STOP
		
; FLAGS 4 & 5 are checked in tdc.lib (_ROM_tdc_dispatch__)

MK_QUERY_FLAG6:
    jcd PIN_TRIGGERED_N, MK_QUERY_FLAG7
        bitS DSP_OUT_2						; From PCap03-> To reset the flip flop for edge triggering
        bitC DSP_OUT_2
		jsb MK_RO_STOP
		
MK_QUERY_FLAG7:
    jcd SPI_TRIGGERED_N, MK_QUERY_HS_MODE			
		nop

MK_QUERY_HS_MODE:
; Checking if HS_MODE (in the externalFlags register) is set
	move	a, b
	sub		a, b				; A <= 0

	jcd HS_MODE_JCD, MK_QUERY_CDC_TRIG_N	; If HS_MODE is configured, then check if CDC_TRIG_N is active
		not a

MK_QUERY_CDC_TRIG_N:
	jcd CDC_TRIGGERED_N, MK_query_a
		not a
	MK_query_a:
	move	b, a
	jEQ		MK_main

	jcd 	true, MK_RO_STOP
		
MK_EOP:

    jcd		CDC_TRIG_BG_N, MK_skip_BG_TRIG
		bitS TRIG_BG
        jsb	MK_load_timer

    MK_skip_BG_TRIG:
    resetWDG

; ------------------------------ wait until CDC_RDY, if Continuous Mode is activated----------------

	load	a, CFG_ADD_C_TRIG_SEL		; Checking if Continuous Mode configured
	push 	mem_add
	move 	r, a
	jsb 	_ROM_memory_rd_a_u08b__
	load 	b, CFG_BM_C_TRIG_SEL
	and 	a, b
	jNE		MK_set_interrupt
		cdc_is_bsy:
		jcd CDC_BSY, cdc_is_bsy			; Wait for busy clearing in continuous mode
	

MK_set_interrupt:
    bitS INTERRUPT_OUT

MK_RO_STOP:	
	stop

		
;----------------------------------------------------------
MK_Initialize:
	load	a, NV_cdc_result_align					; Reading the number of right shifts to be performed on the cdc meas. values
	push 	mem_add
	move 	r, a
	jsb 	_ROM_memory_rd_a_u08b__
	load 	b, NV_cdc_result_align_mask
	and 	a, b
	rad		RAM_CDC_MV_RSHIFT					; Saving the number of right shifts in RAM
	move	r, a							
	
; Checking if the High Speed Mode (HS_MODE) is configured in the External Flag register

	load 	a, CFG_ADD_EXTERNAL_FLAGS			; External Flag register
	push 	mem_add
	move 	r, a
	jsb 	_ROM_memory_rd_a_u08b__

	rad		RAM_EXTERNAL_FLAGS					; Saving a copy of the external flags in RAM for later reuse
	move	r, a

	load	b, CFG_BM_HS_MODE_SEL				; Loading bit mask for HS_MODE_SEL
	and		a, b						
	jEQ		MK_No_HS_Mode
		load2exp	a, HS_MODE 
		push	FLAGREG
		or		r, a
MK_No_HS_Mode:	

    load2exp a, FIRSTSTART_N
    push	FLAGREG
    or		r, a
    jrt

;----------------------------------------------------------	
MK_load_timer:
	;  Loading TIMER0 with BG_TIME
		load	a, NV_BG_TIME				; Getting BG_TIME from NVRAM		
		push	mem_add
		move	r, a
		jsb		_ROM_memory_rd_a_u08b__		; A contains content of NV_BG_TIME 
        rad 	TIMER0
        move 	r, a
        jrt
;----------------------------------------------------------		